@@ -22,9 +22,6 @@
 #include "../include/Operation.h"
 
 #include <parted/parted.h>
-#ifdef HAVE_LIBPARTED_3_1_0_PLUS
-#include <parted/filesys.h>
-#endif
 #include <vector>
 #include <fstream>
 
@@ -57,7 +54,8 @@ public:
 	const std::vector<FS> & get_filesystems() const ;
 	const FS & get_fs( GParted::FILESYSTEM filesystem ) const ;
 	static std::vector<Glib::ustring> get_disklabeltypes() ;
-	std::vector<Glib::ustring> get_all_mountpoints() ;
+	static bool is_dev_mounted( const Glib::ustring & path ) ;
+	static std::vector<Glib::ustring> get_all_mountpoints() ;
 	std::map<Glib::ustring, bool> get_available_flags( const Partition & partition ) ;
 	Glib::ustring get_libparted_version() ;
 	Glib::ustring get_thread_status_message() ;
@@ -66,13 +64,17 @@ public:
 	static bool filesystem_resize_disallowed( const Partition & partition ) ;
 private:
 	//detectionstuff..
-	void init_maps() ;
+	static void init_maps() ;
 	void set_thread_status_message( Glib::ustring msg ) ;
-	void read_mountpoints_from_file( const Glib::ustring & filename,
-					 std::map< Glib::ustring, std::vector<Glib::ustring> > & map ) ;
-	void read_mountpoints_from_file_swaps(
-		const Glib::ustring & filename,
-		std::map< Glib::ustring, std::vector<Glib::ustring> > & map ) ;
+	static void read_mountpoints_from_file( const Glib::ustring & filename,
+	                                        std::map< Glib::ustring, std::vector<Glib::ustring> > & map ) ;
+	static void add_node_and_mountpoint( std::map< Glib::ustring, std::vector<Glib::ustring> > & map,
+	                                     Glib::ustring & node,
+	                                     Glib::ustring & mountpoint ) ;
+	static void read_mountpoints_from_file_swaps( const Glib::ustring & filename,
+	                                              std::map< Glib::ustring, std::vector<Glib::ustring> > & map ) ;
+	static bool have_rootfs_dev( std::map< Glib::ustring, std::vector<Glib::ustring> > & map ) ;
+	static void read_mountpoints_from_mount_command( std::map< Glib::ustring, std::vector<Glib::ustring> > & map ) ;
 	Glib::ustring get_partition_path( PedPartition * lp_partition ) ;
 	void set_device_partitions( Device & device, PedDevice* lp_device, PedDisk* lp_disk ) ;
 	GParted::FILESYSTEM get_filesystem( PedDevice* lp_device, PedPartition* lp_partition,
@@ -86,6 +88,8 @@ private:
 				 Byte_Value sector_size,
 				 bool inside_extended ) ;
 	void set_mountpoints( std::vector<Partition> & partitions ) ;
+	bool set_mountpoints_helper( Partition & partitions, const Glib::ustring & path ) ;
+	bool is_busy( FILESYSTEM fstype, const Glib::ustring & path ) ;
 	void set_used_sectors( std::vector<Partition> & partitions, PedDisk* lp_disk ) ;
 	void mounted_set_used_sectors( Partition & partition ) ;
 #ifdef HAVE_LIBPARTED_FS_RESIZE
@@ -176,8 +180,9 @@ private:
 	bool update_bootsector( const Partition & partition, OperationDetail & operationdetail ) ;
 
 	//general..	
+	bool flush_device( PedDevice * lp_device ) ;
 	bool get_device_and_disk( const Glib::ustring & device_path,
-	                          PedDevice*& lp_device, PedDisk*& lp_disk, bool strict = true ) ;
+	                          PedDevice*& lp_device, PedDisk*& lp_disk, bool strict = true, bool flush = false ) ;
 	void destroy_device_and_disk( PedDevice*& lp_device, PedDisk*& lp_disk ) ;
 	bool commit( PedDisk* lp_disk ) ;
 	bool commit_to_os( PedDisk* lp_disk, std::time_t timeout ) ;
@@ -192,10 +197,6 @@ private:
 	bool probe_devices ;
 	Glib::ustring thread_status_message;  //Used to pass data to show_pulsebar method
 	Glib::RefPtr<Glib::IOChannel> iocInput, iocOutput; // Used to send data to gpart command
-	
-	std::map< Glib::ustring, std::vector<Glib::ustring> > mount_info ;
-	std::map< Glib::ustring, std::vector<Glib::ustring> > fstab_info ;
-	std::map< Glib::ustring, std::vector<Glib::ustring> >::iterator iter_mp ;
 };
 
 } //GParted
