@@ -300,7 +300,8 @@ void Win_GParted::init_toolbar()
 	combo_devices .pack_start( treeview_devices_columns .device ) ;
 	combo_devices .pack_start( treeview_devices_columns .size, false ) ;
 	
-	combo_devices .signal_changed() .connect( sigc::mem_fun(*this, &Win_GParted::combo_devices_changed) );
+	combo_devices_changed_connection =
+		combo_devices .signal_changed() .connect( sigc::mem_fun(*this, &Win_GParted::combo_devices_changed) );
 
 	hbox_toolbar .pack_start( combo_devices, Gtk::PACK_SHRINK ) ;
 }
@@ -577,6 +578,10 @@ void Win_GParted::init_hpaned_main()
 
 void Win_GParted::refresh_combo_devices()
 {
+	// Temporarily block the on change callback while re-creating the device list
+	// behind the combobox to prevent flashing redraw by being redrawn with an empty
+	// device list.
+	combo_devices_changed_connection .block();
 	liststore_devices ->clear() ;
 	
 	menu = manage( new Gtk::Menu() ) ;
@@ -610,7 +615,8 @@ void Win_GParted::refresh_combo_devices()
 		menu ->show_all() ;
 		menubar_main .items()[ 0 ] .get_submenu() ->items()[ 1 ] .set_submenu( *menu ) ;
 	}
-	
+
+	combo_devices_changed_connection .unblock();
 	combo_devices .set_active( current_device ) ;
 }
 
@@ -887,15 +893,21 @@ void Win_GParted::Refresh_Visual()
 
 	set_valid_operations() ;
 
+	// Process Gtk events to redraw visuals with reloaded partition details
+	while ( Gtk::Main::events_pending() )
+		Gtk::Main::iteration();
+
 	if ( largest_unalloc_size >= 0 )
 	{
-		//Inform visuals of selection of the largest unallocated partition
+		// Flashing redraw work around.  Inform visuals of selection of the
+		// largest unallocated partition after drawing those visuals above.
 		drawingarea_visualdisk .set_selected( selected_partition ) ;
 		treeview_detail .set_selected( selected_partition ) ;
-	}
 
-	while ( Gtk::Main::events_pending() ) 
-		Gtk::Main::iteration() ;
+		// Process Gtk events to draw selection
+		while ( Gtk::Main::events_pending() )
+			Gtk::Main::iteration();
+	}
 }
 
 bool Win_GParted::Quit_Check_Operations()
@@ -1442,8 +1454,11 @@ void Win_GParted::show_help_dialog( const Glib::ustring & filename /* E.g., gpar
 
 void Win_GParted::menu_help_contents()
 {
-#ifdef HAVE_DISABLE_DOC
-	//GParted was configured with --disable-doc
+#ifdef ENABLE_HELP_DOC
+	//GParted was built with help documentation
+	show_help_dialog( "gparted", "" );
+#else
+	//GParted was built *without* help documentation using --disable-doc
 	Gtk::MessageDialog dialog( *this,
 			_( "Documentation is not available" ),
 			false,
@@ -1457,9 +1472,6 @@ void Win_GParted::menu_help_contents()
 	tmp_msg += "http://gparted.org" ;
 	dialog .set_secondary_text( tmp_msg ) ;
 	dialog .run() ;
-#else
-	//GParted was configured without --disable-doc
-	show_help_dialog( "gparted", "" );
 #endif
 }
 
@@ -2041,7 +2053,7 @@ void Win_GParted::activate_format( GParted::FILESYSTEM new_fs )
 
 void Win_GParted::unmount_partition( bool * succes, Glib::ustring * error ) 
 {
-	std::vector<Glib::ustring> errors, failed_mountpoints, mountpoints = gparted_core .get_all_mountpoints() ;
+	std::vector<Glib::ustring> errors, failed_mountpoints, mountpoints = GParted_Core::get_all_mountpoints() ;
 	Glib::ustring dummy ;
 
 	*succes = true ; 
