@@ -61,10 +61,12 @@ FS fat16::get_filesystem_support()
 {
 	FS fs ;
 	fs .filesystem = specific_type ;
-		
+
 	// hack to disable silly mtools warnings
 	setenv( "MTOOLS_SKIP_CHECK", "1", 0 );
 
+	fs .busy = FS::GPARTED ;
+
 	//find out if we can create fat file systems
 	if ( ! Glib::find_program_in_path( "mkfs.fat" ) .empty() )
 	{
@@ -106,12 +108,7 @@ FS fat16::get_filesystem_support()
 	fs .grow = GParted::FS::LIBPARTED ;
 	fs .shrink = GParted::FS::LIBPARTED ;
 #endif
-#ifdef HAVE_LIBPARTED_3_0_0_PLUS
 	fs .move = FS::GPARTED ;
-#else
-	fs .move = GParted::FS::LIBPARTED ;
-#endif
-
 	fs .copy = GParted::FS::GPARTED ;
 	fs .online_read = FS::GPARTED ;
 
